@@ -93,6 +93,10 @@ class MetricMod(MetricProcessor):
 
 
 class MetricLogger(MetricProcessor):
+    """
+    @deprecated Use TensorBoardMetricLogger instead
+    """
+
     def __init__(self, path: Union[str, Path]):
         path = Path(path)
         path.mkdir(exist_ok=True, parents=True)
@@ -112,6 +116,27 @@ class MetricLogger(MetricProcessor):
         self.writer.close()
 
 
+class TensorBoardMetricLogger(MetricProcessor):
+    """
+    """
+
+    def __init__(self, tb_summary_writer):
+        self.writer = tb_summary_writer
+
+    def __call__(self, data: MetricType) -> MetricType:
+        iteration = data.pop(Marker.ITERATION, None)
+        if iteration is None:
+            iteration = data.pop(Marker.EPOCH, None)
+        if iteration is not None:
+            for name, value in data.items():
+                self.writer.add_scalar(name, value, iteration)
+
+        return data
+
+    def close(self):
+        self.writer.close()
+
+
 mod_name_train = MetricMod(
     name_fn=lambda name: f"train.{name}",
 )
